import React, { Component, Fragment } from 'react';
import Navbar from './Navbar';
import Footer from './Footer';
import TestCard from './TestCard';
import { getJSON, getHASH, getCustomHASH } from '../lib/cddc.esm';
import CodeBlock from './CodeBlock';

class App extends Component {
    constructor(props) {
        super(props);

        this.state = {
            result: ''
        };

        this.onGetJson = this.onGetJson.bind(this);
        this.onGetHash = this.onGetHash.bind(this);
        this.onGetCustomHash = this.onGetCustomHash.bind(this);
    }

    onGetJson(includeViewPort) {
        const result = getJSON(includeViewPort)
        this.setState({
            result
        });
    }

    onGetHash(includeViewPort) {
        const result = getHASH(includeViewPort);
        this.setState({
            result
        });
    }

    onGetCustomHash() {
        const result = getCustomHASH('test');
        this.setState({
            result
        });
    }

    render() {
        return (
            <Fragment>
                <Navbar></Navbar>
                <div role="main" className="container position-relative">
                    <h1>CDDC JavaScript for modern UIs</h1>
                    <p>
                        CDDC JavaScript for modern UIs is intended to be used in frameworks such as <em>React</em>, <em>Angular</em>, <em>Vue.Js</em>.
                        Script is provided as a ES6 module in a file <code>cddc.esm.js</code> and also as a UMD module in a file <code>cddc.umd.js</code>
                    </p>
                    <p>
                        Script is exposing three functions to use.
                    </p>

                    <CodeBlock>
                        {
                            `/**
* @param {boolean} includeViewport
* @param {callback} callback
* @returns {string} raw finger print
*/
getJSON(includeViewport, callback)`
                        }
                    </CodeBlock>

                    <CodeBlock>
                        {
                            `/**\
 * @param {boolean} includeViewport
 * @param {callback} callback
 * @returns {string} hashed finger print
 */
getHASH(includeViewport, callback)`
                        }
                    </CodeBlock>

                    <CodeBlock>
                        {
                            `/**
 * @param {string} customText
 * @param {callback} callback
 * @returns {string} hashed finger print with custom text included
 */
getCustomHASH(customText, callback)`
                        }
                    </CodeBlock>
                    <h3>Using script as ES6 module</h3>
                    <p>
                        Script is provided as a ES6 module in a file <code>cddc.esm.js</code> and also as a UMD module in a file <code>cddc.umd.js</code>
                    </p>
                    <p>
                        Example of using script <code>cddc.esm.js</code> in a <em>React</em> framework component and <em>Webpack / RollUp</em> module bundler.
                </p>
                    <CodeBlock>
                        {
`//Test.js
import React,{ Component } from 'react';
//including reference to a script
import { getJSON  } from '../lib/cddc.esm';

class Test extends Component {
    constructor(props){
        super(props);

        this.state = {
            fingerprint: '',
            hashedFingerprint: ''
        };
    }

    componentDidMount(){
        //calling function
        const fingerprint = getJSON(false);
        const hashedFingerprint = getHASH(false);
        this.setState({
            fingerprint: fingerprint,
            hashedFingerprint: hashedFingerprint
        });
        ...

    }
}

export default Test`
                        }
                    </CodeBlock>
                    <h3>Using script as UMD module</h3>
                    <p>
                        Script is also provided as a UMD module in a file <code>cddc.umd.js</code> to be used by module loaders like <em>CommonJS</em>, <em>AMD</em>, <em>RequireJS</em> or used without any module loader at all.
                </p>
                    <p>
                        Example of using script <code>cddc.umd.js</code> script with <em>RequireJS</em> module loader is:
                </p>
                    <CodeBlock language="html">
                        {
                            `<!-- index.html -->
<!DOCTYPE html>
<html lang='en'>
<head>
    <meta charset='UTF-8'>
    <meta name='viewport' content='width=device-width, initial-scale=1.0'>
    <title>Document</title>
</head>
<body>
    <script data-main='index.js' src='node_modules/requirejs/require.js'></script>
</body>
</html>`
                        }
                    </CodeBlock>
                    <CodeBlock>
                        {
                            `//index.js
requirejs(['./lib/cddc.umd.js'],function(cddc){
    var fingerprint = cddc.getJSON();
    var hashedFingerprint = cddc.getHASH();

    console.log('fingerprint is ' + fingerprint);
    console.log('hashed fingerprint is ' + hashedFingerprint);
});`
                        }
                    </CodeBlock>
                    <p>
                        Script can be used without any module loader. When script is just included in the header of the web page, global variable <code>window.cddc</code>, exposing all three functions, will be created.
                </p>
                    <p>
                        Example of using <code>cddc.umd.js</code> in a web page without any module loader is:
                </p>
                    <CodeBlock language="html">
                        {
                            `<!-- index.html -->
<!DOCTYPE html>
<html lang='en'>
<head>
    <meta charset='UTF-8'>
    <meta name='viewport' content='width=device-width, initial-scale=1.0'>
    <title>Document</title>
</head>
<body>

    <script src='./lib/cddc.umd.js'></script>
    <script type='text/javascript'>
        var fingerprint = window.cddc.getJSON();
        var hashedFingerprint = window.cddc.getHASH();

        console.log('fingerprint is ' + fingerprint);
        console.log('hashed fingerprint is ' + hashedFingerprint);
    </script>
</body>
</html>`
                        }
                    </CodeBlock>
                    <div class="spacer"></div>
                    <div className='row'>
                        <div className='col-md-4'>
                            <TestCard title='Try call getJSON!' onCalled={this.onGetJson}></TestCard>
                        </div>
                        <div className="col-md-4">
                            <TestCard title='Try call getHASH!' onCalled={this.onGetHash}></TestCard>
                        </div>
                        <div className="col-md-4">
                            <TestCard title='Try call getCustomHASH!' onCalled={this.onGetCustomHash} hideViewPortCheckbox={true}></TestCard>
                        </div>
                    </div>
                    <div className={"row mt-5 " + (this.state.result ? "" : "hidden")}>
                        <div className='col-sm-12'>
                            Result is:
                    </div>
                        <div className='col-sm-12'>
                            <p>{this.state.result}</p>
                        </div>
                    </div>
                </div>
                <Footer></Footer>
            </Fragment>
        );
    }
}

export default App
